# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from anchorbrowser import Anchorbrowser, AsyncAnchorbrowser
from anchorbrowser.types.sessions import RecordingListResponse, RecordingPauseResponse, RecordingResumeResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestRecordings:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Anchorbrowser) -> None:
        recording = client.sessions.recordings.list(
            "session_id",
        )
        assert_matches_type(RecordingListResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Anchorbrowser) -> None:
        response = client.sessions.recordings.with_raw_response.list(
            "session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        recording = response.parse()
        assert_matches_type(RecordingListResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Anchorbrowser) -> None:
        with client.sessions.recordings.with_streaming_response.list(
            "session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            recording = response.parse()
            assert_matches_type(RecordingListResponse, recording, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Anchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            client.sessions.recordings.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_pause(self, client: Anchorbrowser) -> None:
        recording = client.sessions.recordings.pause(
            "session_id",
        )
        assert_matches_type(RecordingPauseResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_pause(self, client: Anchorbrowser) -> None:
        response = client.sessions.recordings.with_raw_response.pause(
            "session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        recording = response.parse()
        assert_matches_type(RecordingPauseResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_pause(self, client: Anchorbrowser) -> None:
        with client.sessions.recordings.with_streaming_response.pause(
            "session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            recording = response.parse()
            assert_matches_type(RecordingPauseResponse, recording, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_pause(self, client: Anchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            client.sessions.recordings.with_raw_response.pause(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_resume(self, client: Anchorbrowser) -> None:
        recording = client.sessions.recordings.resume(
            "session_id",
        )
        assert_matches_type(RecordingResumeResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_resume(self, client: Anchorbrowser) -> None:
        response = client.sessions.recordings.with_raw_response.resume(
            "session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        recording = response.parse()
        assert_matches_type(RecordingResumeResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_resume(self, client: Anchorbrowser) -> None:
        with client.sessions.recordings.with_streaming_response.resume(
            "session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            recording = response.parse()
            assert_matches_type(RecordingResumeResponse, recording, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_resume(self, client: Anchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            client.sessions.recordings.with_raw_response.resume(
                "",
            )


class TestAsyncRecordings:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAnchorbrowser) -> None:
        recording = await async_client.sessions.recordings.list(
            "session_id",
        )
        assert_matches_type(RecordingListResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.sessions.recordings.with_raw_response.list(
            "session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        recording = await response.parse()
        assert_matches_type(RecordingListResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.sessions.recordings.with_streaming_response.list(
            "session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            recording = await response.parse()
            assert_matches_type(RecordingListResponse, recording, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncAnchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            await async_client.sessions.recordings.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_pause(self, async_client: AsyncAnchorbrowser) -> None:
        recording = await async_client.sessions.recordings.pause(
            "session_id",
        )
        assert_matches_type(RecordingPauseResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_pause(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.sessions.recordings.with_raw_response.pause(
            "session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        recording = await response.parse()
        assert_matches_type(RecordingPauseResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_pause(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.sessions.recordings.with_streaming_response.pause(
            "session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            recording = await response.parse()
            assert_matches_type(RecordingPauseResponse, recording, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_pause(self, async_client: AsyncAnchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            await async_client.sessions.recordings.with_raw_response.pause(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_resume(self, async_client: AsyncAnchorbrowser) -> None:
        recording = await async_client.sessions.recordings.resume(
            "session_id",
        )
        assert_matches_type(RecordingResumeResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_resume(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.sessions.recordings.with_raw_response.resume(
            "session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        recording = await response.parse()
        assert_matches_type(RecordingResumeResponse, recording, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_resume(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.sessions.recordings.with_streaming_response.resume(
            "session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            recording = await response.parse()
            assert_matches_type(RecordingResumeResponse, recording, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_resume(self, async_client: AsyncAnchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `session_id` but received ''"):
            await async_client.sessions.recordings.with_raw_response.resume(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .shared import SuccessResponse as SuccessResponse
from .task_list_params import TaskListParams as TaskListParams
from .extension_manifest import ExtensionManifest as ExtensionManifest
from .task_create_params import TaskCreateParams as TaskCreateParams
from .task_list_response import TaskListResponse as TaskListResponse
from .event_signal_params import EventSignalParams as EventSignalParams
from .session_goto_params import SessionGotoParams as SessionGotoParams
from .session_paste_params import SessionPasteParams as SessionPasteParams
from .task_create_response import TaskCreateResponse as TaskCreateResponse
from .event_wait_for_params import EventWaitForParams as EventWaitForParams
from .profile_create_params import ProfileCreateParams as ProfileCreateParams
from .profile_list_response import ProfileListResponse as ProfileListResponse
from .session_copy_response import SessionCopyResponse as SessionCopyResponse
from .session_create_params import SessionCreateParams as SessionCreateParams
from .session_goto_response import SessionGotoResponse as SessionGotoResponse
from .session_scroll_params import SessionScrollParams as SessionScrollParams
from .session_paste_response import SessionPasteResponse as SessionPasteResponse
from .event_wait_for_response import EventWaitForResponse as EventWaitForResponse
from .extension_list_response import ExtensionListResponse as ExtensionListResponse
from .extension_upload_params import ExtensionUploadParams as ExtensionUploadParams
from .session_create_response import SessionCreateResponse as SessionCreateResponse
from .session_scroll_response import SessionScrollResponse as SessionScrollResponse
from .extension_delete_response import ExtensionDeleteResponse as ExtensionDeleteResponse
from .extension_upload_response import ExtensionUploadResponse as ExtensionUploadResponse
from .profile_retrieve_response import ProfileRetrieveResponse as ProfileRetrieveResponse
from .session_retrieve_response import SessionRetrieveResponse as SessionRetrieveResponse
from .tool_fetch_webpage_params import ToolFetchWebpageParams as ToolFetchWebpageParams
from .session_upload_file_params import SessionUploadFileParams as SessionUploadFileParams
from .batch_session_create_params import BatchSessionCreateParams as BatchSessionCreateParams
from .extension_retrieve_response import ExtensionRetrieveResponse as ExtensionRetrieveResponse
from .session_list_pages_response import SessionListPagesResponse as SessionListPagesResponse
from .tool_fetch_webpage_response import ToolFetchWebpageResponse as ToolFetchWebpageResponse
from .session_drag_and_drop_params import SessionDragAndDropParams as SessionDragAndDropParams
from .session_upload_file_response import SessionUploadFileResponse as SessionUploadFileResponse
from .tool_perform_web_task_params import ToolPerformWebTaskParams as ToolPerformWebTaskParams
from .batch_session_create_response import BatchSessionCreateResponse as BatchSessionCreateResponse
from .session_drag_and_drop_response import SessionDragAndDropResponse as SessionDragAndDropResponse
from .tool_perform_web_task_response import ToolPerformWebTaskResponse as ToolPerformWebTaskResponse
from .tool_screenshot_webpage_params import ToolScreenshotWebpageParams as ToolScreenshotWebpageParams
from .batch_session_retrieve_response import BatchSessionRetrieveResponse as BatchSessionRetrieveResponse
from .session_retrieve_downloads_response import SessionRetrieveDownloadsResponse as SessionRetrieveDownloadsResponse
